@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015, 2020, Oracle and/or its affiliates.
+ * Copyright (c) 2015, 2023, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0, as
@@ -141,12 +141,19 @@ public:
 
   virtual ~Op_base() override
   {
+    // Let's aquire lock so that any remaingin replies are consumed on ~Reply
+    // and this way avoid race conditions with Client::close()
+    auto lock = m_sess->lock();
     release_stmt_id();
+    m_reply.reset();
   }
 
   cdk::Session& get_cdk_session()
   {
     assert(m_sess);
+    if (!m_sess->m_sess->is_valid()){
+      THROW("Session is no longer valid");
+    }
     return *(m_sess->m_sess);
   }
 
@@ -335,9 +342,12 @@ public:
 
   Result_init& execute() override
   {
+    auto lock = m_sess->lock();
     // Can not execute operation that is already completed.
     assert(!m_completed);
 
+
+
     execute_prepare();
     wait();
     execute_cleanup();
@@ -844,7 +854,7 @@ public:
     return m_order.empty() ? nullptr : this;
   }
 
-private:
+protected:
 
   // cdk::Order_by interface
 
@@ -881,8 +891,10 @@ private:
 
     prc.list_end();
   }
-};
 
+  using Base::process;
+
+};
 
 /*
   This template adds to the given Base class implementations of Having_if
@@ -931,7 +943,7 @@ public:
     return m_having.empty() ? nullptr : this;
   }
 
-private:
+protected:
 
   // cdk::Expression processor
 
@@ -940,6 +952,8 @@ private:
     parser::Expression_parser expr_parser(PM, m_having);
     expr_parser.process(prc);
   }
+
+  using Base::process;
 };
 
 
@@ -987,7 +1001,7 @@ public:
     return m_group_by.empty() ? nullptr : this;
   }
 
-private:
+protected:
 
   // Expr_list
 
@@ -1003,8 +1017,9 @@ private:
 
     prc.list_end();
   }
-};
 
+  using Base::process;
+};
 
 /*
   This template adds to the given Base class implementations of Proj_if
@@ -1133,6 +1148,8 @@ private:
 
   }
 
+  using Base::process;
+
   // cdk::Projection
 
   void process(cdk::Projection::Processor& prc) const override
@@ -2192,6 +2209,8 @@ public:
     JSON_INSERT(<json>, '$._id', <id>)
 
   where <json> and <id> are given as constructor parameters.
+
+  <id> can either be a string or an expression which generates the <id>
 */
 
 struct Insert_id
@@ -2202,8 +2221,14 @@ struct Insert_id
   typedef cdk::string string;
 
   const cdk::Expression &m_doc;
+  const cdk::Expression *m_id_exr = nullptr;
   std::string  m_id;
 
+  Insert_id(const cdk::Expression &doc, const cdk::Expression &id_expr)
+      : m_doc(doc){
+    m_id_exr = &id_expr;
+  }
+
   Insert_id(const cdk::Expression &doc, const std::string &id)
     : m_doc(doc), m_id(id)
   {}
@@ -2231,7 +2256,11 @@ struct Insert_id
     sprc->list_begin();
     m_doc.process_if(sprc->list_el()); // the document to modify
     sprc->list_el()->scalar()->val()->str("$._id");
-    sprc->list_el()->scalar()->val()->str(m_id);
+    if (m_id_exr) {
+      m_id_exr->process_if(sprc->list_el());
+    } else {
+      sprc->list_el()->scalar()->val()->str(m_id);
+    }
     sprc->list_end();
   }
 
@@ -2390,6 +2419,22 @@ public:
   }
 };
 
+/*
+  Represents an expression which generates _id.
+  In this case, will use the _id column value.
+*/
+struct Extract_id : cdk::Expression {
+  struct : cdk::api::Column_ref {
+    const cdk::api::Table_ref *table() const override { return nullptr; }
+    const cdk::string name() const override { return "_id"; }
+  } m_id;
+
+  Extract_id() {}
+
+  void process(cdk::Expression::Processor &prc) const override {
+    safe_prc(prc)->scalar()->ref(m_id, nullptr);
+  }
+};
 
 /*
   Implementation of collection CRUD modify operation (Collection_modify_if
@@ -2413,6 +2458,12 @@ class Op_collection_modify
 {
   using string = std::string;
   using Impl = common::Collection_modify_if;
+  using Base = Op_select<doc_mode,
+               Op_sort<doc_mode,
+               Op_limit<
+               Op_bind<
+               Op_base<
+                 common::Collection_modify_if>>>>>;
 
   Object_ref m_coll;
 
@@ -2439,12 +2490,29 @@ class Op_collection_modify
       : m_op(op), m_field(field), m_val(val)
     {}
 
-    void process(Processor &prc) const
-    {
-      if (m_expr)
-        return m_expr->process(prc);
+    void process(Processor &prc) const {
+      if (m_expr) return m_expr->process(prc);
 
-      Value::Access::process(parser::Parser_mode::DOCUMENT, m_val, prc);
+      // We send document given by a JSON string as an SQL expression
+      // `JSON_INSERT(val, '$', '{}')` to force server to interpret it as JSON
+      // value. Otherwise it would be interpreted as a literal string value,
+      // not a document.
+      if (Value::JSON == m_val.get_type()) {
+        struct : cdk::api::Object_ref {
+          const cdk::api::Schema_ref *schema() const override {
+            return nullptr;
+          }
+          const cdk::string name() const override { return "JSON_INSERT"; }
+        } json_insert;
+        auto json_set_args = safe_prc(prc.scalar()->call(json_insert));
+        json_set_args->list_begin();
+        json_set_args->list_el()->scalar()->val()->str(m_val.get_string());
+        json_set_args->list_el()->scalar()->val()->str("$");
+        json_set_args->list_el()->scalar()->val()->str("{}");
+        json_set_args->list_end();
+      } else {
+        Value::Access::process(parser::Parser_mode::DOCUMENT, m_val, prc);
+      }
     }
   };
 
@@ -2471,8 +2539,7 @@ public:
     return new Op_collection_modify(*this);
   }
 
-  cdk::Reply* do_send_command() override
-  {
+  cdk::Reply *do_send_command() override {
     // Do nothing if no update specifications were added
 
     if (m_update.empty())
@@ -2574,6 +2641,7 @@ public:
     }
   }
 
+  using Base::process;
 };
 
 
@@ -2605,7 +2673,6 @@ public:
     add_operation(SET, "$", *this);
     add_param("id", id);
   }
-
 };
 
 
@@ -2998,6 +3065,7 @@ protected:
       );
   }
 
+  using Base::process;
 
   //  cdk::api::Column_ref
 
